@@ -5,7 +5,7 @@ import errno
 import os
 import struct
 from dataclasses import dataclass
-from typing import Any, NamedTuple
+from typing import Any, NamedTuple, Optional
 
 # The following modules are not supported on Windows.
 try:
@@ -100,7 +100,7 @@ def set_ctty(child_fd):
 class PtyStreamReaderProtocol(asyncio.StreamReaderProtocol):
     "Custom subclass of StreamReaderProtocol for pty's."
 
-    _pty_child_fd = None
+    _pty_child_fd: Optional[ChildFd] = None
 
     def connection_lost(self, exc):
         "Intercept EIO error and treat it as EOF."
@@ -140,9 +140,8 @@ async def _open_pty_streams(parent_fd: int, child_fd: ChildFd):
         os.fdopen(parent_fd, "rb", 0, closefd=False),
     )
 
-    writer_protocol = asyncio.streams.FlowControlMixin()
     writer_transport, writer_protocol = await loop.connect_write_pipe(
-        lambda: writer_protocol,
+        asyncio.streams.FlowControlMixin,
         os.fdopen(parent_fd, "wb", 0, closefd=True),
     )
     writer = asyncio.StreamWriter(writer_transport, writer_protocol, reader, loop)
@@ -154,7 +153,7 @@ async def _open_pty_streams(parent_fd: int, child_fd: ChildFd):
         _orig_close()
         reader_transport.close()
 
-    writer_transport.close, _orig_close = _close, writer_transport.close
+    writer_transport.close, _orig_close = _close, writer_transport.close  # type: ignore
 
     return reader, writer
 
@@ -189,8 +188,8 @@ def cbreak(rows=0, cols=0):
     return _pty_set_cbreak
 
 
-def canonical(rows=0, cols=0, echo=True):
-    "Return a function that leaves PtyOptions.child_fd in canonical mode."
+def cooked(rows=0, cols=0, echo=True):
+    "Return a function that leaves PtyOptions.child_fd in cooked mode."
 
     if Ellipsis in (rows, cols):
         rows, cols = _inherit_term_size(rows, cols)
