@@ -160,8 +160,9 @@ class _RunOptions:  # pylint: disable=too-many-instance-attributes
         )
 
         # Set up PTY here. This is the first half. Second half in `Runner`.
-        start_new_session = options._start_new_session
-        preexec_fn = options._preexec_fn
+        start_session = options._start_new_session  # pylint: disable=protected-access
+        preexec_fn = options._preexec_fn  # pylint: disable=protected-access
+
         if options.pty:
             assert preexec_fn is None
             stdin, stdout, stderr, preexec_fn = self._setup_pty1(
@@ -170,7 +171,7 @@ class _RunOptions:  # pylint: disable=too-many-instance-attributes
                 stderr,
                 options.pty,
             )
-            start_new_session = True
+            start_session = True
 
         self.input_bytes = input_bytes
         self.kwd_args = {
@@ -178,7 +179,7 @@ class _RunOptions:  # pylint: disable=too-many-instance-attributes
             "stdout": stdout,
             "stderr": stderr,
             "env": options.merge_env(),
-            "start_new_session": start_new_session,
+            "start_new_session": start_session,
             "preexec_fn": preexec_fn,
             "close_fds": options.close_fds,
         }
@@ -209,8 +210,6 @@ class _RunOptions:  # pylint: disable=too-many-instance-attributes
             # Custom support for Redirect constants.
             if input_ == Redirect.INHERIT:
                 stdin = sys.stdin
-            elif input_ == Redirect.IGNORE:
-                input_bytes = None
             else:
                 # CAPTURE uses stdin == PIPE.
                 assert input_ == Redirect.CAPTURE
@@ -293,8 +292,6 @@ class _RunOptions:  # pylint: disable=too-many-instance-attributes
 
         if stderr == asyncio.subprocess.STDOUT:
             stderr = child_fd
-        elif stderr == asyncio.subprocess.PIPE:
-            raise RuntimeError("pty can't separate stderr from stdout")
 
         return stdin, stdout, stderr, lambda: pty_util.set_ctty(child_fd)
 
@@ -501,7 +498,7 @@ class Runner:
 
             # Assign pty streams.
             if opts.pty_fds:
-                assert (stdin, stdout, stderr) == (None, None, None)
+                assert (stdin, stdout) == (None, None)
                 stdin, stdout = opts.pty_fds.writer, opts.pty_fds.reader
 
             if stderr is not None:
@@ -960,11 +957,7 @@ class PipeRunner:  # pylint: disable=too-many-instance-attributes
 
 
 def _is_multiple_capture(cmd):
-    "Return true if stdin is CAPTURE or both stdout and stderr are CAPTURE."
-    input_ = Redirect.from_default(cmd.options.input, 0, cmd.options.pty)
-    if input_ == Redirect.CAPTURE:
-        return True
-
+    "Return true if both stdout and stderr are CAPTURE."
     output = Redirect.from_default(cmd.options.output, 1, cmd.options.pty)
     error = Redirect.from_default(cmd.options.error, 2, cmd.options.pty)
     return output == Redirect.CAPTURE and error == Redirect.CAPTURE
